<?php
namespace WCStepFilter;

add_shortcode('woocommerce-step-filter', __NAMESPACE__. '\\appShortCode');

if (!function_exists(__NAMESPACE__ . '\\appShortCode')) {
    function appShortCode($attributes)
    {
        // if have no WooCommerce or is the admin part (and not AJAX) or Elementor preview
        if (!Core::$wcIsActive
            || (is_admin() && !defined('DOING_AJAX')
                && (!class_exists('\Elementor\Plugin') || !\Elementor\Plugin::$instance->editor->is_edit_mode()))
        ) {
            return 'woocommerce-step-filter';
        }

        do_action('wcsf_shortcode', $attributes);

        return Core::getTemplatePart('index', $attributes, ['echo' => false]);
    }
}

add_shortcode('wcsf-result-pdf-page-number', __NAMESPACE__. '\\resultPDFPageNumberShortCode');

if (!function_exists(__NAMESPACE__ . '\\resultPDFPageNumberShortCode')) {
    function resultPDFPageNumberShortCode()
    {
        return '<span class="wcsf-result-pdf-page-number"></span>';
    }
}

add_shortcode('wcsf-result-pdf-page-total', __NAMESPACE__. '\\resultPDFPageTotalShortCode');

if (!function_exists(__NAMESPACE__ . '\\resultPDFPageTotalShortCode')) {
    function resultPDFPageTotalShortCode()
    {
        $pageCount = Instance()->currentResultsPDFTotalPages;

        if (!$pageCount) {
            return '';
        }

        return '<span class="wcsf-result-pdf-page-total">' . $pageCount . '</span>';
    }
}

add_shortcode('wcsf-value-input', __NAMESPACE__. '\\valueInputShortCode');

if (!function_exists(__NAMESPACE__ . '\\valueInputShortCode')) {
    function valueInputShortCode($attributes = [])
    {
        $filterId = Instance()->currentId;
        $questionId = Instance()->currentQuestionId;
        $defaults = [
            'class' => '',
            'name' => '',
            'type' => 'text',
            'value' => '',
            'data-component' => 'wcsf-field-input wcsf-value-input'
        ];

        $attributes = array_replace($defaults, (array) $attributes);
        $unsupportedTypes = ['button', 'image', 'reset', 'submit'];
        $unsupportedTypes = apply_filters('wcsf_step_input_short_code_unsupported_types', $unsupportedTypes);

        if (in_array($attributes['type'], $unsupportedTypes)) {
            return '';
        }

        $filterValue = Filter::getValue($filterId);
        $actionOnClick = Question::getSetting($questionId, 'action_on_click');

        if ($actionOnClick != 'none') {
            $attributes['data-component'] .= ' wcsf-' . $actionOnClick;
        } elseif (Filter::getSetting($filterId, 'show_preliminary_results_count')) {
            $attributes['data-component'] .= ' wcsf-get-preliminary-results-count';
        }

        if ($filterValue && isset($filterValue[$questionId], $filterValue[$questionId][$attributes['name']])) {
            if (in_array($attributes['type'], ['checkbox', 'radio'])) {
                if ($filterValue[$questionId][$attributes['name']] == $attributes['value']) {
                    $attributes['checked'] = 'checked';
                }
            } elseif ($attributes['type'] != 'hidden') {
                $attributes['value'] = $filterValue[$questionId][$attributes['name']];
            }
        }

        $attributes['name'] = "value[{$questionId}][{$attributes['name']}]";

        return '<input ' . Utils::attributesArrayToString($attributes) . '>';
    }
}
