(function (root, factory) {
    'use strict';

    if (typeof define === 'function' && define.amd) {
        define(['jquery'], factory);
    } else if (typeof exports === 'object'
        && typeof module !== 'undefined'
        && typeof require === 'function'
    ) {
        module.exports = factory(require('jquery'));
    } else {
        factory(root.jQuery);
    }
})(this, function ($) {
    'use strict';

    const $document = $(document);
    const $body = $(document.body);

    $document
        .ready(() => {
            $('[data-component~="wcsf-data-table-body-item"][data-key="source"] :input').each(function () {
                const $input = $(this);

                $input.closest('[data-component~="wcsf-data-table-body-item"]').attr('data-value', $input.val());
            });
        })

        // re-launch some js fields
        .on('added.value.question.wcsf', (event, instance, $element) => {
            $body.trigger('wc-enhanced-select-init');
            $document.trigger('init.thumbnail.wcsf');
            $document.trigger('init.ajaxSelect.wcsf');

            $element.find('[data-component~="wcsf-data-table-body-item"][data-key="source"] :input').each(function () {
                const $input = $(this);

                $input.closest('[data-component~="wcsf-data-table-body-item"]').attr('data-value', $input.val());
            });
        })

        // extra query setting source change
        .on('change', '[data-component~="wcsf-data-table-body-item"][data-key="source"] :input', function () {
            const $input = $(this);

            $input.closest('[data-component~="wcsf-data-table-body-item"]').attr('data-value', $input.val());
        })

        // data-table new item
        .on('added.item.dataTable.wcsf', () => {
            $body.trigger('wc-enhanced-select-init');
            $document.trigger('init.thumbnail.wcsf');
            $document.trigger('init.ajaxSelect.wcsf');
        })

        // open modal via JS too to be sure everything is alright (some 3rd code makes it wrong)
        .on('click', '[data-component~="wcsf-open-modal"]', function (event) {
            event.preventDefault();

            const href = $(this).attr('href');

            $(href).addClass('is-opened');

            if (history.pushState) {
                history.pushState(null, null, href);
            } else {
                location.hash = href;
            }
        })

        // close modal
        .on('click', '[data-component~="wcsf-modal-close"]', function () {
            $(this).closest('[data-component~="wcsf-modal"]').removeClass('is-opened');

            if (history.pushState) {
                history.pushState(null, null, '#');
            } else {
                location.hash = '#';
            }
        })

        // toggle settings group
        .on('click', '[data-component~="wcsf-settings-group-toggle"]', function (event) {
            event.preventDefault();

            const $element = $(this);
            const $groups = $element.closest('[data-component~="wcsf-settings-groups"]');
            const $content = $groups.find('[data-component~="wcsf-settings-group-content"]');
            const $selectedContent = $content.filter(`[data-id="${$element.data('id')}"]`);

            if ($selectedContent.hasClass('is-visible')) {
                $selectedContent.removeClass('is-visible');

                return this;
            }

            $content.removeClass('is-visible');
            $selectedContent.toggleClass('is-visible');

            return this;
        })

        // inquiries pagination
        .on('click', '[data-component~="wcsf-inquiry-list-pagination-item-link"]', function (event) {
            event.preventDefault();

            const $element = $(this);
            const $table = $element.closest('[data-component~="wcsf-inquiry-list-table"]');

            $table.addClass('is-loading');

            return $.get(
                $table.data('ajax-url'),
                {
                    action: 'WCSFGetInquiriesListTable',
                    filterId: $table.data('filter-id'),
                    total: $table.data('total'),
                    page: $element.data('page')
                },
                (response) => $table.replaceWith(response)
            );
        })

        // purge inquiries
        .on('click', '[data-component~="wcsf-inquiries-purge"]', function (event) {
            if (!confirm('Confirm')) {
                event.preventDefault();
            }
        });
});
