/* wcStepFilterQuestion
 * Original author: troll_winner@mail.ru
 * Further changes, comments: troll_winner@mail.ru
 */

(function (root, factory) {
    'use strict';

    if (typeof define === 'function' && define.amd) {
        define(['jquery'], factory);
    } else if (typeof exports === 'object'
        && typeof module !== 'undefined'
        && typeof require === 'function'
    ) {
        module.exports = factory(require('jquery'));
    } else {
        factory(root.jQuery);
    }
})(this, function ($) {
    'use strict';

    const pluginName = 'wcStepFilterQuestion';
    const defaults = {};
    const $document = $(document);

    const Plugin = function (element, options) {
        this.element = element;
        this.options = $.extend({}, defaults, options);

        return this.init();
    };

    /**
     * Init the instance
     * @returns {Object} self instance
     */
    Plugin.prototype.init = function () {
        const _this = this;

        this.$element = $(this.element);
        this.$settings = this.$element.find('[data-component~="wcsf-setting"]');
        this.$manualValues = this.$element.find('[data-component~="wcsf-question-manual-values"]');
        this.$filterType = this.$element.find('#_filter_type');
        this.$filterTypes = this.$filterType.find('option');
        this.$viewType = this.$element.find('#_view_type');
        this.ajaxUrl = this.$element.data('ajax-url');

        this.toggleFields();

        // disable not active manual source inputs
        this.$element
            .find('[data-component~="wcsf-question-manual-value-filter"].is-closed')
            .find(':input:not([data-component~="wcsf-question-manual-value-filter-by"])')
            .attr('disabled', true);

        this.$element
            .on('change', '#_view_type, #_filter_type', () => this.toggleFields())

            // add manual filter row
            .on('click', '[data-component~="wcsf-question-add-value"]', function (event) {
                event.preventDefault();

                const $element = $(this);

                $element.attr('disabled', true);

                return _this
                    .addValue()
                    .then(() => $element.attr('disabled', false));
            })

            // remove manual filter row
            .on('click', '[data-component~="wcsf-question-manual-value-remove"]', function (event) {
                event.preventDefault();

                const $element = $(this);
                const $value = _this.$element.find('[data-component~="wcsf-question-manual-value"]');
                const $valueToRemove = $value.filter(`[data-index="${$element.data('index')}"]`);

                if ($value.length !== 1) {
                    $valueToRemove.remove();

                    _this.recalculate();
                }
            });

        return this;
    };

    /**
     * Show/hide fields
     * @returns {Object} self instance
     */
    Plugin.prototype.toggleFields = function () {
        let filterType = this.$filterType.val();
        const viewType = this.$viewType.val();
        const numericViews = ['number', 'number-from', 'number-to', 'number-between'];
        const checkboxViews = ['checkbox', 'image-checkbox', 'chips-checkbox', 'button-checkbox'];
        const multiChoiceViews = ['multi-choice-checkbox', 'multi-choice-range'];
        const imagedViews = ['image-radio', 'image-checkbox'];
        const singleValueViews = ['select', 'radio', 'image-radio', 'chips-radio', 'button-radio'];

        const typesVisibilityRules = {
            price: ['formula', ...numericViews],
            manual: [...singleValueViews, ...checkboxViews],
            category: [...checkboxViews, ...singleValueViews, ...multiChoiceViews],
            tag: [...checkboxViews, ...singleValueViews, ...multiChoiceViews],
            meta: [
                'formula',
                'select',
                'radio',
                'checkbox',
                'chips-radio',
                'chips-checkbox',
                'button-radio',
                'button-checkbox',
                ...multiChoiceViews,
                ...numericViews
            ]
        };

        const settingsVisibilityRulesByView = {
            formula: ['formula'],
            formula_operator: ['formula'],
            formula_variables: ['formula'],
            formula_name_aliases: ['formula'],
            formula_value_aliases: ['formula'],
            output_formula_value: ['formula'],
            formula_value_text: ['formula'],
            from_value_text: ['number-from', 'number-between'],
            to_value_text: ['number-to', 'number-between'],
            numeric_unit: numericViews,
            numeric_step: numericViews,
            enable_slider: numericViews,
            show_slider_tooltips: numericViews,
            show_inputs: numericViews,
            label_as_placeholder: numericViews,
            attribute_value_source: ['formula', ...numericViews],
            add_any_product_value: singleValueViews,
            any_product_value_text: singleValueViews,
            any_product_value_checked: singleValueViews,
            any_product_value_position: singleValueViews,
            any_product_value_thumbnail: ['image-radio'],
            add_empty_value: ['select'],
            empty_value_text: ['select'],
            alignment: imagedViews,
            thumbnail_size: imagedViews,
            multi_choice_values: multiChoiceViews,
            multi_choice_undefined_value_text: multiChoiceViews,
            multi_choice_possible_value_text: multiChoiceViews,
            multi_choice_required_value_text: multiChoiceViews,
            multi_choice_excluded_value_text: multiChoiceViews,
            hide_empty_terms: [...checkboxViews, ...singleValueViews],
            included_terms: [...checkboxViews, ...singleValueViews],
            excluded_terms: [...checkboxViews, ...singleValueViews],
            unmet_values_behavior: [...checkboxViews, ...singleValueViews],
            show_count: [...checkboxViews, ...singleValueViews, ...multiChoiceViews],
            action_on_click: [...checkboxViews, ...singleValueViews, ...multiChoiceViews],
            additional_get_param: [...checkboxViews, ...singleValueViews, ...numericViews],
            additional_get_param_term_source: [...checkboxViews, ...singleValueViews],
            min_values_selected: checkboxViews,
            min_values_selected_message: checkboxViews,
            max_values_selected: checkboxViews,
            max_values_selected_message: checkboxViews,
            relation: checkboxViews
        };

        const settingsVisibilityRulesByType = {
            attribute: ['attribute'],
            attribute_value_source: ['attribute'],
            add_any_product_value: ['attribute', 'tag', 'category', 'meta'],
            any_product_value_text: ['attribute', 'tag', 'category', 'meta'],
            any_product_value_checked: ['attribute', 'tag', 'category', 'meta'],
            any_product_value_position: ['attribute', 'tag', 'category', 'meta'],
            any_product_value_thumbnail: ['attribute', 'tag', 'category', 'meta'],
            additional_get_param_term_source: ['attribute', 'tag', 'category'],
            category_parent: ['category'],
            category_parent_by_question: ['category'],
            start_from_categories_level: ['category'],
            max_sub_categories_level: ['category'],
            hide_empty_terms: ['attribute', 'tag', 'category'],
            included_terms: ['attribute', 'tag', 'category'],
            excluded_terms: ['attribute', 'tag', 'category'],
            show_count: ['attribute', 'tag', 'category'],
            manual: ['manual'],
            meta_key: ['meta'],
            relation: ['attribute', 'tag', 'category', 'meta']
        };

        // toggle types according to the selected view
        this.$filterTypes.each(function () {
            const $element = $(this);

            if (!typesVisibilityRules.hasOwnProperty($element.attr('value'))) {
                return null;
            }

            const hide = $.inArray(viewType, typesVisibilityRules[$element.attr('value')]) === -1;

            $element.attr('disabled', hide);

            return this;
        });

        // reset select if disabled option was selected
        if (!this.$filterType.val()) {
            this.$filterType.val(this.$filterType.find('option:not(disabled):eq(0)').attr('value'));
            filterType = this.$filterType.val();
        }

        // toggle settings according to the selected view
        this.$settings.each(function () {
            const $element = $(this);

            if (!settingsVisibilityRulesByView.hasOwnProperty($element.data('key'))) {
                return null;
            }

            const hide = $.inArray(viewType, settingsVisibilityRulesByView[$element.data('key')]) === -1;

            $element[hide ? 'addClass' : 'removeClass']('is-hidden-by-view');

            return this;
        });

        // toggle settings according to the selected type
        this.$settings.each(function () {
            const $element = $(this);

            if (!settingsVisibilityRulesByType.hasOwnProperty($element.data('key'))) {
                return null;
            }

            const hide = $.inArray(filterType, settingsVisibilityRulesByType[$element.data('key')]) === -1;

            $element[hide ? 'addClass' : 'removeClass']('is-hidden-by-type');

            return this;
        });

        return this;
    };

    /**
     * Makes the ajax-request and add manual value fields row
     * @returns {Promise} ajax request
     */
    Plugin.prototype.addValue = function () {
        const data = {
            action: 'wcsfAddQuestionValue',
            postId: this.$element.data('post-id'),
            index: this.$manualValues.find('[data-component~="wcsf-question-manual-value"]').length
        };

        return $.get(
            this.ajaxUrl,
            data,
            (response) => {
                this.$manualValues.append(response);

                const $element = this.$manualValues.find('[data-component~="wcsf-question-manual-value"]:last');

                $document.trigger('added.value.question.wcsf', [this, $element]);
            }
        );
    };

    /**
     * ReCalculate input names indexes
     * @return {Object} jQuery elements
     */
    Plugin.prototype.recalculate = function () {
        return this.$element
            .find('[data-component~="wcsf-question-manual-value"]')
            .each(function (index) {
                const $element = $(this);

                // change item index
                $element.attr('data-index', index);

                // change item children index
                $element
                    .find('[data-index]')
                    .each(function () {
                        return $(this).attr('data-index', index);
                    });

                return $element
                    .find(':input')
                    .each(function () {
                        const $input = $(this);
                        const name = $input.attr('name');

                        if (!name) {
                            return this;
                        }

                        const number = index.toString().split('').reverse()
                            .join('');

                        // replace the first array key from the end
                        return $input.attr(
                            'name',
                            name
                                .split('')
                                .reverse()
                                .join('')
                                .replace(/]\d+\[/, `]${number}[`)
                                .split('')
                                .reverse()
                                .join('')
                        );
                    });
            });
    };

    $.fn[pluginName] = function (options) {
        return this.each(function () {
            if (!$.data(this, 'wcsf-question')) {
                $.data(this, 'wcsf-question', new Plugin(this, options));
            }
        });
    };

    const init = () => $('[data-component~="wcsf-question"]').each(function () {
        return $(this).wcStepFilterQuestion();
    });

    $document
        .ready(() => init())
        .on('init.wcStepFilterQuestion', () => init())

        // toggle manual filter source sections
        .on('change', '[data-component~="wcsf-question-manual-value-filter-by"]', function () {
            const $section = $(this)
                .closest('[data-component~="wcsf-modal"]')
                .find('[data-component~="wcsf-question-manual-value-filter"]');

            $section.addClass('is-closed')
                .find(':input:not([data-component~="wcsf-question-manual-value-filter-by"])')
                .attr('disabled', true);

            $section.filter(`[data-id="${$(this).data('id')}"]`).removeClass('is-closed')
                .find(':input')
                .removeAttr('disabled');
        });
});
