(function (root, factory) {
    'use strict';

    if (typeof define === 'function' && define.amd) {
        define(['jquery'], factory);
    } else if (typeof exports === 'object'
        && typeof module !== 'undefined'
        && typeof require === 'function'
    ) {
        module.exports = factory(require('jquery'));
    } else {
        factory(root.jQuery);
    }
})(this, function ($) {
    'use strict';

    const $document = $(document);
    const init = () => {
        $('[data-component~="wcsf"]').each(function () {
            const $element = $(this);

            return $element.wcsf($element.data('options') || {});
        });
    };

    if (typeof document.wcsf === 'undefined') {
        document.wcsf = {};
    }

    document.wcsf.tooltip = (function () {
        let hideTimeout = null;

        return {
            template: '<span class="wcsf-tooltip" data-component="wcsf-tooltip" role="tooltip" '
                + ' aria-hidden="false">%text%</span>',
            fadeDuration: 200,
            hideDelay: 2500,
            hideAll: function () {
                this.hide($('[data-component~="wcsf-tooltip"]'));

                return this;
            },
            hide: function ($element) {
                if ($element.length <= 0) {
                    return this;
                }

                $element.fadeOut(this.fadeDuration, () => $element.remove());

                return this;
            },
            show: function ($element, text) {
                this.hideAll();

                clearTimeout(hideTimeout);

                const $tooltip = $(this.template.replace('%text%', text));

                $element.before($tooltip);

                hideTimeout = setTimeout(() => this.hide($tooltip), this.hideDelay);

                return this;
            }
        };
    })();

    $document
        // init
        .ready(() => init())
        .on('init.wcsf', () => init())

        // reset click
        .on('click.reset.wcsf', '[data-component~="wcsf-reset"]', function (event) {
            const $element = $(this);
            const $wcsf = $element.closest('[data-component~="wcsf"]');

            if ($wcsf.data('wcsf')) {
                event.preventDefault();

                return $wcsf.data('wcsf').reset();
            }

            return this;
        })

        // value item remove click
        .on('click.remove.value.wcsf', '[data-component~="wcsf-value-item-remove"]', function (event) {
            const $element = $(this);
            const $wcsf = $element.closest('[data-component~="wcsf"]');

            if ($wcsf.data('wcsf')) {
                event.preventDefault();

                return $wcsf.data('wcsf').reset({resetStepId: $element.data('id')});
            }

            return this;
        })

        // submit and go to click
        .on('click.submitAndGoTo.wcsf', '[data-component~="wcsf-submit-and-go-to"]', function (event) {
            const $element = $(this);
            const $wcsf = $element.closest('[data-component~="wcsf"]');

            if ($wcsf.data('wcsf')) {
                if (!$wcsf.data('wcsf').checkFromValidity()) {
                    return this;
                }

                if ($element.prop('nodeName') === 'BUTTON') {
                    event.preventDefault();
                }

                return $wcsf.data('wcsf').submitAndGoTo({stepId: $element.data('id')});
            }

            return this;
        })

        // submit and go next click
        .on('click.submitAndGoNext.wcsf', '[data-component~="wcsf-submit-and-go-next"]', function (event) {
            const $element = $(this);
            const $wcsf = $element.closest('[data-component~="wcsf"]');

            if ($wcsf.data('wcsf')) {
                if (!$wcsf.data('wcsf').checkFromValidity()) {
                    return this;
                }

                if ($element.prop('tagName') === 'BUTTON') {
                    event.preventDefault();
                }

                return $wcsf.data('wcsf').submitAndGoNext({stepId: $element.data('id')});
            }

            return this;
        })

        // submit and go to results click
        .on('click.submitAndGoResults.wcsf', '[data-component~="wcsf-submit-and-go-results"]', function (event) {
            const $element = $(this);
            const $wcsf = $element.closest('[data-component~="wcsf"]');

            if ($wcsf.data('wcsf')) {
                if (!$wcsf.data('wcsf').checkFromValidity()) {
                    return this;
                }

                if ($element.prop('tagName') === 'BUTTON') {
                    event.preventDefault();
                }

                return $wcsf.data('wcsf').submitAndGoResults({stepId: $element.data('id')});
            }

            return this;
        })

        // submit click
        .on('click.submit.wcsf', '[data-component~="wcsf-submit"]', function (event) {
            const $element = $(this);
            const $wcsf = $element.closest('[data-component~="wcsf"]');

            if ($wcsf.data('wcsf')) {
                if (!$wcsf.data('wcsf').checkFromValidity()) {
                    return this;
                }

                if ($element.prop('tagName') === 'BUTTON') {
                    event.preventDefault();
                }

                return $wcsf.data('wcsf').submit({stepId: $element.data('id')});
            }

            return this;
        })

        // results click
        .on('click.results.wcsf', '[data-component~="wcsf-results"]', function () {
            const $element = $(this);
            const $wcsf = $element.closest('[data-component~="wcsf"]');

            if ($wcsf.data('wcsf')) {
                if (!$wcsf.data('wcsf').checkFromValidity()) {
                    return this;
                }

                // need to submit the form via usual request (without js)
                $wcsf.data('wcsf').$element.find('[data-component="wcsf-form"]').attr('js-off', true);
            }

            return this;
        })

        // none action button click
        .on('click.results.wcsf', '[data-component~="wcsf-none"]', function () {
            return false;
        })

        // submit form
        .on('submit.form.wcsf', '[data-component="wcsf-form"]:not([js-off="true"])', function (event) {
            const $element = $(this);
            const $wcsf = $element.closest('[data-component~="wcsf"]');

            if ($wcsf.data('wcsf')) {
                if (!$wcsf.data('wcsf').checkFromValidity()) {
                    return this;
                }

                event.preventDefault();

                return $wcsf.data('wcsf').submitAndGoNext();
            }

            return this;
        })

        // get step click
        .on('click.getStep.wcsf', '[data-component~="wcsf-get-step"]', function (event) {
            const $element = $(this);
            const $wcsf = $element.closest('[data-component~="wcsf"]');

            if ($wcsf.data('wcsf')) {
                event.preventDefault();

                return $wcsf.data('wcsf').getStep({
                    stepId: $element.data('id'),
                    page: $element.data('page') ? $element.data('page') : 1
                });
            }

            return this;
        })

        // hide tooltips on click
        .on('click.tooltips.wcsf', '[data-component~="wcsf"]', () => document.wcsf.tooltip.hideAll())

        // get preliminary results count
        .on(
            'change.getPreliminaryResults.wcsf changed.getPreliminaryResults.wcsf',
            '[data-component~="wcsf-get-preliminary-results-count"]',
            function () {
                const $element = $(this);
                const $wcsf = $element.closest('[data-component~="wcsf"]');

                if ($wcsf.data('wcsf')) {
                    document.wcsf.tooltip.hideAll();

                    return $wcsf.data('wcsf').getPreliminaryResultsCount($element);
                }

                return this;
            }
        )

        // get preliminary results count manual trigger
        .on(
            'getPreliminaryResultsCount.wcsf',
            (event, instance, data, $element) => document.wcsf.tooltip.show($element, data.message)
        )

        // products order change
        .on('change.order.wcsf', '[data-component~="wcsf-ordering-select"]', function (event) {
            const $element = $(this);
            const $wcsf = $element.closest('[data-component~="wcsf"]');

            if ($wcsf.data('wcsf')) {
                event.preventDefault();

                return $wcsf.data('wcsf').getStep({
                    stepId: $element.data('id'),
                    orderby: $element.val(),
                    page: 1
                });
            }

            return this;
        })

        // WCSF ajax complete
        .on('ajaxCompleted.wcsf', () => {
            // noUi slider init
            $document.trigger('init.nouislider.wcsf');
        });
});
