<?php
defined('ABSPATH') || exit;

use \WCStepFilter\Core;

$question = isset($question) ? $question : null;

if (!$question) {
    return;
}

$arguments = Core::getTemplatePartArgs(
    [
        'question' => null,
        'fields' => [],
        'sliderOptions' => [
            'orientation' => 'horizontal',
            'start' => [0],
            'range' => [
                'min' => 0,
                'max' => 100
            ],
            'step' => 1,
            'format' => ['decimals' => 0],
            'connect' => [true, false],
            'binding' => [],
            'tooltips' => [$question->showSliderTooltips]
        ]
    ],
    ['recursive' => true]
);
?>
<div class="wcsf-field is-number-from">
    <?php
    $field = reset($arguments['fields']);
    $fieldKeys = array_keys($arguments['fields']);
    $fieldKey = reset($fieldKeys);
    $fieldId = "wcsf-field-$fieldKey-$arguments[id]-{$question->id}";
    $placeholder = $question->labelAsPlaceholder ? $field->label . ' ' . $field->min : '';
    $value = $field->value != $field->min ? $field->value : '';

    if ($question->enableSlider) {
        $arguments['sliderOptions']['binding'][] = "#$fieldId";
        $arguments['sliderOptions']['start'] = [$field->value];
        $arguments['sliderOptions']['step'] = $field->step;
        $arguments['sliderOptions']['format']['decimals'] = strlen(substr(strrchr($field->step, '.'), 1));
        $arguments['sliderOptions']['range'] = [
            'min' => $field->min,
            'max' => $field->max
        ];
        ?>
        <div class="wcsf-field-slider-wrapper">
            <div class="wcsf-field-slider horizontal"
                data-component="wcsf-no-ui-slider"
                data-options="<?php echo esc_attr(wp_json_encode($arguments['sliderOptions'])); ?>"></div>
            <?php if (!$question->showInputs) { ?>
                <label for="<?php echo esc_attr($fieldId); ?>"
                    class="wcsf-field-label sr-only"><?php echo wp_kses_post($field->label); ?></label>
                <input type="number"
                    step="<?php echo esc_attr($field->step); ?>"
                    id="<?php echo esc_attr($fieldId); ?>"
                    class="wcsf-field-input sr-only"
                    data-component="<?php echo esc_attr($field->component); ?>"
                    name="<?php echo esc_attr($field->name); ?>"
                    placeholder="<?php echo esc_attr($placeholder); ?>"
                    value="<?php echo esc_attr($value); ?>">
            <?php } ?>
        </div>
        <?php
    }

    if ($question->showInputs) {
        ?>
        <div class="form-group">
            <?php if ($question->labelAsPlaceholder) { ?>
                <label for="<?php echo esc_attr($fieldId); ?>"
                    class="wcsf-field-label sr-only"><?php echo wp_kses_post($field->label); ?></label>
            <?php } ?>
            <div class="input-group">
                <?php if (!$question->labelAsPlaceholder) { ?>
                    <span class="input-group-addon input-group-prepend">
                        <label for="<?php echo esc_attr($fieldId); ?>"
                            class="wcsf-field-label input-group-text"><?php
                            echo wp_kses_post($field->label);
                            ?></label>
                    </span>
                <?php } ?>
                <input type="number"
                    step="<?php echo esc_attr($field->step); ?>"
                    id="<?php echo esc_attr($fieldId); ?>"
                    class="form-control wcsf-field-input"
                    data-component="<?php echo esc_attr($field->component); ?>"
                    name="<?php echo esc_attr($field->name); ?>"
                    placeholder="<?php echo esc_attr($placeholder); ?>"
                    value="<?php echo esc_attr($value); ?>">
            </div>
        </div>
        <?php
    }
    ?>
</div>
