<?php
defined('ABSPATH') || exit;

use \WCStepFilter\Core;
use \WCStepFilter\Filter;

$id = isset($id) ? $id : null;

if (!$id) {
    throw new Exception('Empty filter id');
}

$arguments = Core::getTemplatePartArgs([
    'id' => $id,
    'showHeader' => Filter::getSetting($id, 'show_header'),
    'showFooter' => Filter::getSetting($id, 'show_footer'),
    'navView' => Filter::getSetting($id, 'nav_view'),
    'navItems' => Filter::getNavItems($id),
    'mode' => Filter::getSetting($id, 'mode'),
    'enableValue' => Filter::getSetting($id, 'enable_value'),
    'resultsUrl' => Filter::getSetting($id, 'results_url'),
    'step' => Filter::getActiveStep($id),
    'steps' => Filter::getSteps($id),
    'nextButtonText' => Filter::getSetting($id, 'next_button_text'),
    'nextStepId' => Filter::getNextActiveStepId($id),
    'prevStepId' => Filter::getPrevActiveStepId($id),
    'value' => Filter::getValue($id)
]);

$arguments['activeStep'] = (array) $arguments['step']; // older versions support
$bodyTemplate = in_array($arguments['mode'], ['single-step', 'sequence']) ? 'single' : 'tabs';

do_action('wcsf_before_output', $arguments);
?>
<form class="wcsf-form"
    id="wcsf-form-<?php echo esc_attr($arguments['id']); ?>"
    action="?paged=1#"
    method="POST"
    data-component="wcsf-form"
    data-step-id="<?php echo esc_attr($arguments['step']->id); ?>">
    <?php // no-js keyboard version of submit. should be upper the other ?>
    <button type="submit"
        class="sr-only"
        name="stepId"
        value="<?php echo esc_attr($arguments['nextStepId']); ?>"
        data-component="wcsf-submit-and-go-next"
        data-id="<?php echo esc_attr($arguments['step']->id); ?>"><?php
        echo wp_kses_post($arguments['nextButtonText']);
        ?></button>
    <input type="hidden" name="id" value="<?php echo esc_attr($arguments['id']); ?>">
    <input type="hidden" name="wcsf" value="<?php echo esc_attr($arguments['id']); ?>">
    <input type="hidden" name="stepId" value="<?php echo esc_attr($arguments['step']->id); ?>">
    <?php
    if ($bodyTemplate == 'tabs') {
        Core::getTemplatePart('nav/index', $arguments);
    }

    if ($arguments['showHeader']) {
        Core::getTemplatePart('header', $arguments);
    }

    if ($arguments['enableValue']) {
        Core::getTemplatePart('value', $arguments);
    }

    Core::getTemplatePart("body/${bodyTemplate}", $arguments);

    if ($arguments['showFooter']) {
        Core::getTemplatePart('footer', $arguments);
    }
    ?>
</form>
<?php do_action('wcsf_after_output', $arguments); ?>
