<?php
defined('ABSPATH') || exit;

use \WCStepFilter\Core;
use \WCStepFilter\Filter;

$id = isset($id) ? $id : null;

if (!$id) {
    throw new Exception('Empty filter id');
}

$arguments = Core::getTemplatePartArgs([
    'id' => $id,
    'navView' => Filter::getSetting($id, 'nav_view'),
    'mode' => Filter::getSetting($id, 'mode'),
    'maxResultsNumber' => Filter::getSetting($id, 'max_results_number'),
    'page' => max(1, get_query_var('paged')),
    'orderby' => isset($_REQUEST['orderby'])
        ? wc_clean(wp_unslash($_REQUEST['orderby']))
        : apply_filters('woocommerce_default_catalog_orderby', get_option('woocommerce_default_catalog_orderby'))
]);

$productsQuery = new WP_Query(Filter::getProductsQueryArgs($id, $arguments));

do_action('wcsf_products_query', $id, $arguments, $productsQuery);

// change max products count
if ($arguments['maxResultsNumber']) {
    $productsQuery->post_count = min($arguments['maxResultsNumber'], $productsQuery->post_count);
    $productsQuery->found_posts = min($arguments['maxResultsNumber'], $productsQuery->found_posts);
}

$arguments['productsQuery'] = $productsQuery;

echo '<section class="wcsf-products woocommerce">';

if (in_array($arguments['mode'], ['single-step', 'sequence'])) {
    Core::getTemplatePart('controls/index', $arguments);

    if ($arguments['enableValue']) {
        Core::getTemplatePart('value', $arguments);
    }
}

if ($productsQuery->have_posts()) {
    echo '<div class="wcsf-products-controls clearfix">';

    Core::getTemplatePart('products/order-by', $arguments);
    Core::getTemplatePart('products/result-count', $arguments);
    Core::getTemplatePart('products/pagination', $arguments);

    echo '</div>';

    woocommerce_product_loop_start();

    while ($productsQuery->have_posts()) {
        $productsQuery->the_post();

        do_action('woocommerce_shop_loop');
        wc_get_template_part('content', 'product');
    }

    woocommerce_product_loop_end();

    echo '<div class="wcsf-products-controls clearfix">';

    Core::getTemplatePart('products/order-by', $arguments);
    Core::getTemplatePart('products/result-count', $arguments);
    Core::getTemplatePart('products/pagination', $arguments);

    echo '</div>';
} else {
    /**
     * Hook: woocommerce_no_products_found.
     *
     * @hooked wc_no_products_found - 10
     */
    do_action('woocommerce_no_products_found');
}

echo '</section>';

$productsQuery->reset_postdata();
wp_reset_postdata();
wp_reset_query();
