<?php
defined('ABSPATH') || exit;

$arguments = \WCStepFilter\Core::getTemplatePartArgs([
    'orderby' => isset($_REQUEST['orderby'])
        ? wc_clean(wp_unslash($_REQUEST['orderby']))
        : apply_filters('woocommerce_default_catalog_orderby', get_option('woocommerce_default_catalog_orderby'))
]);

$orderByOptions = apply_filters(
    'woocommerce_catalog_orderby',
    [
        'menu_order' => __('Default sorting', 'woocommerce'),
        'popularity' => __('Sort by popularity', 'woocommerce'),
        'rating' => __('Sort by average rating', 'woocommerce'),
        'date' => __('Sort by newness', 'woocommerce'),
        'price' => __('Sort by price: low to high', 'woocommerce'),
        'price-desc' => __('Sort by price: high to low', 'woocommerce')
    ]
);

if ('no' === get_option('woocommerce_enable_review_rating')) {
    unset($orderByOptions['rating']);
}

if (is_array($orderByOptions) && !array_key_exists((string) $arguments['orderby'], $orderByOptions)) {
    $arguments['orderby'] = current(array_keys($orderByOptions));
}
?>
<div class="wcsf-products-ordering woocommerce-ordering" data-component="wcsf-ordering">
    <select name="orderBy" class="wcsf-products-ordering-value"
        aria-label="<?php esc_attr_e('Shop order', 'woocommerce'); ?>"
        data-component="wcsf-ordering-select">
        <?php foreach ($orderByOptions as $optionId => $optionName) { ?>
            <option value="<?php echo esc_attr($optionId); ?>" <?php
                selected($arguments['orderby'], $optionId);
                ?>><?php echo esc_html($optionName); ?></option>
        <?php } ?>
    </select>
    <noscript>
        <button type="submit"
            class="wcsf-products-ordering-submit my-1 btn btn-secondary btn-sm"><?php
            esc_html_e('Apply order', 'woocommerce-step-filter');
            ?></button>
    </noscript>
</div>
