<?php
defined('ABSPATH') || exit;

$id = isset($id) ? $id : null;

if (!$id) {
    throw new Exception('Empty filter id');
}

use \WCStepFilter\Core;
use \WCStepFilter\Filter;
use \WCStepFilter\Utils;

$arguments = Core::getTemplatePartArgs([
    'resultsPdfHeaderContent' => Filter::getSetting($id, 'results_pdf_header_content'),
    'resultsPdfHeaderHeight' => Filter::getSetting($id, 'results_pdf_header_height'),
    'resultsPdfFooterContent' => Filter::getSetting($id, 'results_pdf_footer_content'),
    'resultsPdfFooterHeight' => Filter::getSetting($id, 'results_pdf_footer_height'),
    'resultsPdfTopDescription' => Filter::getSetting($id, 'results_pdf_top_description'),
    'resultsPdfBottomDescription' => Filter::getSetting($id, 'results_pdf_bottom_description'),
    'productsQueryArgs' => Filter::getProductsQueryArgs($id),
    'maxResultsNumber' => Filter::getSetting($id, 'max_results_number'),
    'enableValue' => Filter::getSetting($id, 'enable_value')
]);
?>
<style>
    @page {
        size: A4;
        margin: <?php
        echo ($arguments['resultsPdfHeaderHeight'] + 1) . 'cm 1.5cm ' . ($arguments['resultsPdfFooterHeight'] + 1) . 'cm';
        ?>;
    }

    body {
        font-family: DejaVu Sans, sans-serif;
    }

    .wcsf-result-pdf-header,
    .wcsf-result-pdf-footer {
        position: fixed;
        left: -1.5cm;
        right: -1.5cm;
        width: 21cm;
    }

    .wcsf-result-pdf-header {
        top: <?php echo '-' . ($arguments['resultsPdfHeaderHeight'] + 1) . 'cm'; ?>;
        height: <?php echo "{$arguments['resultsPdfHeaderHeight']}cm"; ?>;
    }

    .wcsf-result-pdf-footer {
        bottom: <?php echo '-' . ($arguments['resultsPdfFooterHeight'] + 1) . 'cm'; ?>;
        height: <?php echo "{$arguments['resultsPdfFooterHeight']}cm"; ?>;
    }

    .wcsf-result-pdf-description {
        clear: both;
    }

    .wcsf-result-pdf-page-number::after {
        content: counter(page);
    }

    .wcsf-results-pdf-products {
        width: 100%;
        border-collapse: separate;
        border-spacing: 0.5em;
        table-layout: fixed;
    }

    .wcsf-results-pdf-product {
        page-break-inside: avoid;
        margin-bottom: 2em;
    }

    .wcsf-results-pdf-product-title {
        margin-bottom: 0.5em;
        font-weight: normal;
        font-size: 1.1em;
        line-height: 1;
    }

    .wcsf-results-pdf-product-title-link {
        font-weight: bolder;
        text-decoration: none;
        color: inherit;
    }

    .wcsf-results-pdf-product-thumbnail {
        display: block;
        width: 100%;
        height: auto;
    }

    .wcsf-results-pdf-product-thumbnail-link {
        display: block;
        padding: 0.25em;
        border: 1px solid #ccc;
        border-radius: 0.15em;
    }

    .wcsf-results-pdf-product-price {
        margin-bottom: 1em;
        font-weight: normal;
    }

    .wcsf-value-item-remove {
        display: none;
    }

    td,
    th {
        vertical-align: top;
    }
</style>
<div class="wcsf-result-pdf-header"><?php
    echo Utils::replaceImagesToBase64InHtml(apply_filters('the_content', $arguments['resultsPdfHeaderContent']));
    ?></div>
<div class="wcsf-result-pdf-footer"><?php
    echo Utils::replaceImagesToBase64InHtml(apply_filters('the_content', $arguments['resultsPdfFooterContent']));
    ?></div>
<div class="wcsf-result-pdf-description top"><?php
    echo Utils::replaceImagesToBase64InHtml(apply_filters('the_content', $arguments['resultsPdfTopDescription']));
    ?></div>
<?php
$productsQuery = new WP_Query($arguments['productsQueryArgs']);

do_action('wcsf_products_pdf_query', $id, $arguments, $productsQuery);

// change max products count
if ($arguments['maxResultsNumber']) {
    $productsQuery->post_count = min($arguments['maxResultsNumber'], $productsQuery->post_count);
    $productsQuery->found_posts = min($arguments['maxResultsNumber'], $productsQuery->found_posts);
}

$arguments['productsQuery'] = $productsQuery;

echo '<div class="woocommerce">';

if ($arguments['enableValue']) {
    Core::getTemplatePart('value', $arguments);
}

if ($productsQuery->have_posts()) {
    $loop = 1;
    $columns = wc_get_loop_prop('columns');

    echo '<table class="wcsf-results-pdf-products"><tr>';

    while ($productsQuery->have_posts()) {
        $productsQuery->the_post();

        global $product;

        if (!$product instanceof \WC_Product) {
            continue;
        }
        ?>
        <td>
            <div class="wcsf-results-pdf-product">
                <?php
                $path = Utils::getThumbnailPath($product->get_image_id(), 'shop_catalog');

                if ($path) {
                    ?>
                    <a class="wcsf-results-pdf-product-thumbnail-link" href="<?php echo $product->get_permalink(); ?>">
                        <img src="<?php echo esc_url($path); ?>"
                            alt="<?php echo $product->get_name(); ?>"
                            class="wcsf-results-pdf-product-thumbnail">
                    </a>
                    <?php
                }
                ?>
                <h3 class="wcsf-results-pdf-product-title">
                    <a class="wcsf-results-pdf-product-title-link" href="<?php echo $product->get_permalink(); ?>"><?php
                        echo $product->get_name();
                        ?></a>
                </h3>
                <div class="wcsf-results-pdf-product-price"><?php
                    echo wc_price($product->get_price());
                    ?></div>
            </div>
        </td>
        <?php
        if ($loop++ == $columns) {
            $loop = 1;

            echo '</tr><tr>';
        }
    }

    echo '</tr></table>';
} else {
    /**
     * Hook: woocommerce_no_products_found.
     *
     * @hooked wc_no_products_found - 10
     */
    do_action('woocommerce_no_products_found');
}

echo '</div>';
?>
<div class="wcsf-result-pdf-description bottom"><?php
    echo Utils::replaceImagesToBase64InHtml(apply_filters('the_content', $arguments['resultsPdfBottomDescription']));
    ?></div>
